\name{checkTableConsistency}
\alias{checkTableConsistency}
\title{Check consistency of input table to \code{\link{runComparison}}}
\usage{
checkTableConsistency(file.table)
}
\arguments{
  \item{file.table}{A data frame with columns named
  \code{input.files} and (optionally) \code{datasets},
  \code{nbr.samples}, \code{repl}, \code{de.methods}.}
}
\value{
Returns a consistent file table defining the result files
that will be used as the basis for a method comparison.
}
\description{
Check that the \code{dataset}, \code{nbr.samples},
\code{repl} and \code{de.methods} columns of a data frame
are consistent with the information provided in the input
files (given in the \code{input.files} column of the data
frame). If there are inconsistencies or missing information
in any of the columns, replace the given information with
the information in the input files.
}
\examples{
mydata.obj <- generateSyntheticData(dataset = "mydata", n.vars = 1000,
                                    samples.per.cond = 5, n.diffexp = 100,
                                    output.file = "mydata.rds")
runDiffExp(data.file = "mydata.rds", result.extent = "voom.limma",
           Rmdfunction = "voom.limma.createRmd", output.directory = ".",
           norm.method = "TMM")
runDiffExp(data.file = "mydata.rds", result.extent = "ttest",
           Rmdfunction = "ttest.createRmd", output.directory = ".",
           norm.method = "TMM")

## A correct table
file.table <- data.frame(input.files = c("mydata_voom.limma.rds", "mydata_ttest.rds"),
                         datasets = c("mydata", "mydata"),
                         nbr.samples = c(5, 5),
                         repl = c(1, 1),
                         stringsAsFactors = FALSE)
new.table <- checkTableConsistency(file.table)
new.table

## An incorrect table
file.table <- data.frame(input.files = c("mydata_voom.limma.rds", "mydata_ttest.rds"),
                         datasets = c("mydata", "mydata"),
                         nbr.samples = c(5, 3),
                         repl = c(2, 1),
                         stringsAsFactors = FALSE)
new.table <- checkTableConsistency(file.table)
new.table

## A table with missing information
file.table <- data.frame(input.files = c("mydata_voom.limma.rds", "mydata_ttest.rds"),
                         stringsAsFactors = FALSE)
new.table <- checkTableConsistency(file.table)
new.table
}
\author{
Charlotte Soneson
}

